"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const assumeRoleResponse = {};
const assumeRole = jest.fn().mockImplementation(() => {
    return Promise.resolve(assumeRoleResponse);
});
jest.mock('@aws-sdk/client-sts', () => {
    return {
        STS: jest.fn().mockImplementation(() => {
            return {
                assumeRole,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const stsHelperMock = new helper_1.STSHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.STSHelper.name}.${stsHelperMock.AssumeRoleAsync.name}`, () => {
    const action = `${helper_1.STSHelper.name}.${stsHelperMock.AssumeRoleAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} roleArn`, () => {
        const actual = stsHelperMock.AssumeRoleAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} roleArn`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = stsHelperMock.AssumeRoleAsync(TestValues.Arn);
        return expect(actual).resolves.toEqual(assumeRoleResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map